@@ -818,8 +818,8 @@ mod tests {
         assert_eq!([FloatDuration::milliseconds(50.0),
                     FloatDuration::milliseconds(30.0),
                     FloatDuration::zero()]
-                       .iter()
-                       .sum::<FloatDuration>(),
+                           .iter()
+                           .sum::<FloatDuration>(),
                    FloatDuration::milliseconds(80.0));
         assert_eq!([FloatDuration::days(2.0)].iter().sum::<FloatDuration>(),
                    FloatDuration::days(2.0));
@@ -856,10 +856,10 @@ mod tests {
     #[cfg(feature = "chrono")]
     #[test]
     fn test_chrono_timepoint() {
-        use chrono::{TimeZone, UTC, Local};
+        use chrono::{TimeZone, Utc, Local};
 
-        let date1 = UTC.ymd(2017, 5, 25).and_hms(10, 0, 0);
-        let date2 = UTC.ymd(2017, 5, 26).and_hms(12, 0, 0);
+        let date1 = Utc.ymd(2017, 5, 25).and_hms(10, 0, 0);
+        let date2 = Utc.ymd(2017, 5, 26).and_hms(12, 0, 0);
 
         assert_eq!(date2.float_duration_since(date1).unwrap(),
                    FloatDuration::days(1.0) + FloatDuration::hours(2.0));
